# Generated by Django 5.0.1 on 2024-02-07 22:53

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0060_historicalicpreferral_locale_created_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalicpreferral",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="repeat_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="repeat_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="repeat_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="repeat_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="icpreferral",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="repeat_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
    ]
