# Generated by Django 5.0.8 on 2024-08-28 19:29

import django_db_views.migration_functions
import django_db_views.operations
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0040_auto_20240824_0412"),
    ]

    operations = []
