# Generated by Django 5.2.3 on 2025-06-25 20:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0222_alter_historicalstudymedication_stock_codes_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultsgludummy",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultslipids",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsgludummy",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipids",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="errors",
            field=models.TextField(blank=True, null=True),
        ),
    ]
