# Generated by Django 5.1.2 on 2024-10-16 01:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0052_lastimpvisit"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="LastImpVisit",
            new_name="LastImpRefill",
        ),
        migrations.AlterModelOptions(
            name="lastimprefill",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "verbose_name": "Last IMP Refill",
                "verbose_name_plural": "Last IMP Refills",
            },
        ),
        migrations.RenameIndex(
            model_name="lastimprefill",
            new_name="meta_report_subject_bc8268_idx",
            old_name="meta_report_subject_4a9e15_idx",
        ),
    ]
