# Generated by Django 4.2.11 on 2024-06-18 02:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="PatientHistoryMissingBaselineCd4",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField()),
                ("visit_code", models.CharField(max_length=25)),
                ("visit_code_sequence", models.IntegerField()),
                ("cd4", models.IntegerField(verbose_name="Last CD4")),
                ("cd4_date", models.DateField(verbose_name="Date of last CD4")),
                ("user_created", models.CharField(max_length=25)),
                ("user_modified", models.CharField(max_length=25)),
                ("modified", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Patient History: Missing Baseline Cd4",
                "verbose_name_plural": "Missing Baseline Cd4",
                "db_table": "patient_history_missing_baseline_cd4",
                "managed": False,
            },
        ),
        migrations.AlterModelOptions(
            name="unattendedthreeinrow",
            options={
                "managed": False,
                "verbose_name": "R100: Unattended appointments: Three in a row",
                "verbose_name_plural": "R100: Unattended appointments: Three in a row",
            },
        ),
        migrations.AlterModelOptions(
            name="unattendedthreeinrow2",
            options={
                "managed": False,
                "verbose_name": "R110: Unattended appointments: Three in a row (with missed)",
                "verbose_name_plural": "R110: Unattended appointments: Three in a row (with missed)",
            },
        ),
        migrations.AlterModelOptions(
            name="unattendedtwoinrow",
            options={
                "managed": False,
                "verbose_name": "R120: Unattended appointments: Two in a row",
                "verbose_name_plural": "R120: Unattended appointments: Two in a row",
            },
        ),
    ]
