CLINICAL_WITHDRAWAL = "clinical_withdrawal"
CLINICIAN = "clinician"
COMPLETED_FOLLOWUP_48 = "completed_followup_48"
DEATH_REPORT_ACTION = "submit_death_report"
DEVIATION = "protocol_deviation"
DM_REFFERAL_ACTION = "dm_refferal_action"
INVESTIGATOR = "investigator"
INVESTIGATOR_DECISION = "investigator_decision"
LATE_EXCLUSION = "late_exclusion"
LOSS_TO_FOLLOWUP_ACTION = "submit_loss_to_followup"
OFFSCHEDULE_DM_REFERRAL_ACTION = "offschedule_dm_referral_action"
OFFSCHEDULE_POSTNATAL_ACTION = "offschedule_postnatal_action"
OFFSCHEDULE_PREGNANCY_ACTION = "offschedule_pregnancy_action"
OFFSTUDY_MEDICATION_ACTION = "withdrawal_study_medication_action"
OTHER_RX_DISCONTINUATION = "other_treatment_discontinuation"
PREGNANCY_NOTIFICATION_ACTION = "pregancy_notification_action"
PROTOCOL_DEVIATION_VIOLATION_ACTION = "submit-protocol-deviation-violation"
REFERRAL = "referral"
SAE = "sae"
UNBLINDING_REQUEST_ACTION = "unblinding-request"
UNBLINDING_REVIEW_ACTION = "unblinding-review"
VIOLATION = "protocol_violation"
