# Generated by Django 3.0.6 on 2020-06-17 14:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0009_auto_20200613_2041"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="subjectvisitmissedreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ["display_index", "display_name"],
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
            },
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissedreasons",
            name="meta_lists__id_50745c_idx",
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="meta_lists__id_4ee3a4_idx",
            ),
        ),
    ]
