# Generated by Django 3.2.4 on 2021-06-28 18:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0020_auto_20200524_1944"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalicpreferral",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalicpreferral",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalicpreferral",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="calculated_bmi",
            new_name="calculated_bmi_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="calculated_egfr",
            new_name="calculated_egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="converted_creatinine",
            new_name="converted_creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="converted_fasting_glucose",
            new_name="converted_ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="converted_ogtt_two_hr",
            new_name="converted_ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="urine_bhcg",
            new_name="urine_bhcg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="calculated_bmi",
            new_name="calculated_bmi_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="calculated_egfr",
            new_name="calculated_egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="converted_creatinine",
            new_name="converted_creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="converted_fasting_glucose",
            new_name="converted_ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="converted_ogtt_two_hr",
            new_name="converted_ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="urine_bhcg",
            new_name="urine_bhcg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="calculated_bmi",
            new_name="calculated_bmi_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="calculated_egfr",
            new_name="calculated_egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="converted_creatinine",
            new_name="converted_creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="converted_fasting_glucose",
            new_name="converted_ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="converted_ogtt_two_hr",
            new_name="converted_ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="urine_bhcg",
            new_name="urine_bhcg_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="calculated_bmi",
            new_name="calculated_bmi_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="calculated_egfr",
            new_name="calculated_egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="converted_creatinine",
            new_name="converted_creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="converted_fasting_glucose",
            new_name="converted_ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="converted_ogtt_two_hr",
            new_name="converted_ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="urine_bhcg",
            new_name="urine_bhcg_value",
        ),
        migrations.RenameField(
            model_name="icpreferral",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="icpreferral",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="icpreferral",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="calculated_bmi",
            new_name="calculated_bmi_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="calculated_egfr",
            new_name="calculated_egfr_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="converted_creatinine",
            new_name="converted_creatinine_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="converted_fasting_glucose",
            new_name="converted_ifg_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="converted_ogtt_two_hr",
            new_name="converted_ogtt_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="urine_bhcg",
            new_name="urine_bhcg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="Units (Blood glucose 2hrs after...)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
    ]
