# Generated by Django 4.2.11 on 2024-04-04 16:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0057_historicalonscheduledmreferral_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dmreferral",
            name="referral_note",
            field=models.TextField(
                null=True,
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmreferral",
            name="referral_note",
            field=models.TextField(
                null=True,
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
    ]
