# Generated by Django 2.2.7 on 2019-11-19 20:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0015_auto_20191107_2249"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="fasting_glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="ogtt_two_hr_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="fasting_glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="ogtt_two_hr_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="fasting_glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="ogtt_two_hr_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="fasting_glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="ogtt_two_hr_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="fasting_glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="ogtt_two_hr_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
    ]
