# Generated by Django 3.2.4 on 2021-07-10 19:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0024_auto_20210710_1929"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="staying_nearby",
            new_name="staying_nearby_6",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="staying_nearby",
            new_name="staying_nearby_6",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="staying_nearby",
            new_name="staying_nearby_6",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="staying_nearby",
            new_name="staying_nearby_6",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="staying_nearby",
            new_name="staying_nearby_6",
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
    ]
