# Generated by Django 3.2.6 on 2021-08-23 20:53

import edc_vitals.models.fields.blood_pressure
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0027_auto_20210804_0438"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="dia_blood_pressure_avg",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Blood pressure: diastolic (average)",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="dia_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="dia_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="sys_blood_pressure_avg",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Blood pressure: systolic (average)"
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="sys_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="sys_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="dia_blood_pressure_avg",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Blood pressure: diastolic (average)",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="dia_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="dia_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="sys_blood_pressure_avg",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Blood pressure: systolic (average)"
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="sys_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="sys_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="dia_blood_pressure_avg",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Blood pressure: diastolic (average)",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="dia_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="dia_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="sys_blood_pressure_avg",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Blood pressure: systolic (average)"
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="sys_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="sys_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="dia_blood_pressure_avg",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Blood pressure: diastolic (average)",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="dia_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="dia_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="sys_blood_pressure_avg",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Blood pressure: systolic (average)"
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="sys_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="sys_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="dia_blood_pressure_avg",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Blood pressure: diastolic (average)",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="dia_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="dia_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="sys_blood_pressure_avg",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Blood pressure: systolic (average)"
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="sys_blood_pressure_one",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="sys_blood_pressure_two",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="part_three_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 3 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="part_two_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 2 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="part_three_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 3 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="part_two_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 2 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="part_three_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 3 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="part_two_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 2 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="part_three_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 3 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="part_two_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 2 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="part_three_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 3 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="part_two_report_datetime",
            field=models.DateTimeField(
                help_text="Date and time of report.",
                null=True,
                verbose_name="Part 2 report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
    ]
